##  Overview
The dashboard is the central hub where you can consolidate and present key information and metrics about your enterprise architecture management data in an organized and easily accessible way. You can use reports, diagrams, charts, graphs, and summaries to provide a quick overview of your enterprise architecture management data and performance.
Dashboards make it easier to identify trends and patterns and help you effectively communicate your insights to different stakeholders. They play a vital role in strategic planning by helping C-level stakeholders make informed decisions and stay aligned with organizational goals.
Dashboards offer a comprehensive and real-time overview and can serve as a centralized hub for tracking progress and identifying areas that require attention or action by displaying new and pending action items, surveys, and more. When you sign in to SAP LeanIX, you automatically land on the default dashboard. You can navigate between the dashboards available to you using the left-side navigation pane.
![Example Default Dashboard](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275165cc7a44101491d0ccd9ec84b101_LowRes.png)
Example Default Dashboard
This guide covers how you can create and edit dashboards to consolidate data from various sources into a single, easy-to-navigate view, enhancing communication and oversight. To learn about various administrative settings that workspace admins can manage, see [Dashboards Settings](https://help.sap.com/docs/leanix/ea/dashboards-settings?locale=en-US&state=PRODUCTION&version=CLOUD "Configure dashboard settings and add specific dashboards to the workspace.").
